@@ -1,70 +1,52 @@
-# ABSTRACT: Perl 5 API wrapper for Twitter.com
+# ABSTRACT: Twitter.com API Client
 package API::Twitter;
 
-use API::Twitter::Class;
+use namespace::autoclean -except => 'has';
 
-extends 'API::Twitter::Client';
+use Data::Object::Class;
+use Data::Object::Class::Syntax;
+use Data::Object::Signatures;
 
-use Carp ();
+use Data::Object qw(load);
+use Data::Object::Library qw(Str);
 use Net::OAuth ();
-use Scalar::Util ();
+
+extends 'API::Client';
+
+our $VERSION = '0.03'; # VERSION
+
+our $DEFAULT_URL = "https://api.twitter.com";
 
 $Net::OAuth::PROTOCOL_VERSION = Net::OAuth::PROTOCOL_VERSION_1_0A;
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
-has access_token => (
-    is       => 'rw',
-    isa      => Str,
-    required => 0,
-);
+# ATTRIBUTES
 
-has access_token_secret => (
-    is       => 'rw',
-    isa      => Str,
-    required => 0,
-);
+has consumer_key        => rw;
+has consumer_secret     => rw;
+has access_token        => rw;
+has access_token_secret => rw;
+has oauth_type          => rw;
 
-has identifier => (
-    is       => 'rw',
-    isa      => Str,
-    default  => 'API::Twitter (Perl)',
-);
+# CONSTRAINTS
 
-has consumer_key => (
-    is       => 'rw',
-    isa      => Str,
-    required => 1,
-);
+req consumer_key        => Str;
+req consumer_secret     => Str;
+opt access_token        => Str;
+opt access_token_secret => Str;
+opt oauth_type          => Str;
 
-has consumer_secret => (
-    is       => 'rw',
-    isa      => Str,
-    required => 1,
-);
+# DEFAULTS
 
-has oauth_type => (
-    is       => 'rw',
-    isa      => Str,
-    default  => 'protected resource',
-);
+def identifier => 'API::Twitter (Perl)';
+def oauth_type => 'protected resource';
+def url        => method { load('Mojo::URL')->new($DEFAULT_URL) };
+def version    => '1.1';
 
-has version => (
-    is       => 'rw',
-    isa      => Str,
-    default  => '1.1',
-);
+# CONSTRUCTION
 
-method AUTOLOAD () {
-    my ($package, $method) = our $AUTOLOAD =~ /^(.+)::(.+)$/;
-    Carp::croak "Undefined subroutine &${package}::$method called"
-        unless Scalar::Util::blessed $self && $self->isa(__PACKAGE__);
-
-    # return new resource instance dynamically
-    return $self->resource($method, @_);
-}
-
-method BUILD () {
+after BUILD => method {
     my $identifier = $self->identifier;
     my $version    = $self->version;
     my $agent      = $self->user_agent;
@@ -75,7 +57,9 @@ method BUILD () {
     $url->path("/$version");
 
     return $self;
-}
+};
+
+# METHODS
 
 method PREPARE ($ua, $tx, %args) {
     my $req     = $tx->req;
@@ -125,28 +109,6 @@ method PREPARE ($ua, $tx, %args) {
     $headers->header('Authorization' => $oauth->to_authorization_header);
 }
 
-method action ($method, %args) {
-    $method = uc($method || 'get');
-
-    # execute transaction and return response
-    return $self->$method(%args);
-}
-
-method create (%args) {
-    # execute transaction and return response
-    return $self->POST(%args);
-}
-
-method delete (%args) {
-    # execute transaction and return response
-    return $self->DELETE(%args);
-}
-
-method fetch (%args) {
-    # execute transaction and return response
-    return $self->GET(%args);
-}
-
 method resource (@segments) {
     # build new resource instance
     my $instance = __PACKAGE__->new(
@@ -173,11 +135,6 @@ method resource (@segments) {
     return $instance;
 }
 
-method update (%args) {
-    # execute transaction and return response
-    return $self->PUT(%args);
-}
-
 1;
 
 __END__
@@ -188,11 +145,11 @@ __END__
 
 =head1 NAME
 
-API::Twitter - Perl 5 API wrapper for Twitter.com
+API::Twitter - Twitter.com API Client
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -221,166 +178,18 @@ version 0.02
 This distribution provides an object-oriented thin-client library for
 interacting with the Twitter (L<http://twitter.com>) API. For usage and
 documentation information visit L<https://dev.twitter.com/rest/public>.
+API::Twitter is derived from L<API::Client> and inherits all of it's
+functionality. Please read the documentation for API::Client for more
+usage information.
 
-=head1 THIN CLIENT
-
-A thin-client library is advantageous as it has complete API coverage and
-can easily adapt to changes in the API with minimal effort. As a thin-client
-library, this module does not map specific HTTP requests to specific routines,
-nor does it provide parameter validation, pagination, or other conventions
-found in typical API client implementations, instead, it simply provides a
-simple and consistent mechanism for dynamically generating HTTP requests.
-Additionally, this module has support for debugging and retrying API calls as
-well as throwing exceptions when 4xx and 5xx server response codes are
-returned.
-
-=head2 Building
-
-    my $user = $twitter->users('lookup');
-
-    $user->action;          # GET /users/lookup
-    $user->action('head');  # HEAD /users/lookup
-    $user->action('patch'); # PATCH /users/lookup
-
-Building up an HTTP request object is extremely easy, simply call method names
-which correspond to the API's path segments in the resource you wish to execute
-a request against. This module uses autoloading and returns a new instance with
-each method call. The following is the equivalent:
-
-=head2 Chaining
-
-    my $users = $twitter->resource('users');
-
-    # or
-
-    my $users = $twitter->users;
-    my $user  = $users->resource('lookup');
-
-    # then
-
-    $user->action('put', %args); # PUT /users/lookup
-
-Because each call returns a new API instance configured with a resource locator
-based on the supplied parameters, reuse and request isolation are made simple,
-i.e., you will only need to configure the client once in your application.
-
-=head2 Fetching
-
-    my $users = $twitter->users;
-
-    # query-string parameters
-
-    $users->fetch( query => { ... } );
-
-    # equivalent to
-
-    my $users = $twitter->resource('users');
-
-    $users->action( get => ( query => { ... } ) );
-
-This example illustrates how you might fetch an API resource.
-
-=head2 Creating
-
-    my $users = $twitter->users;
-
-    # content-body parameters
-
-    $users->create( data => { ... } );
-
-    # query-string parameters
-
-    $users->create( query => { ... } );
-
-    # equivalent to
-
-    $twitter->resource('users')->action(
-        post => ( query => { ... }, data => { ... } )
-    );
-
-This example illustrates how you might create a new API resource.
-
-=head2 Updating
-
-    my $users = $twitter->users;
-    my $user  = $users->resource('lookup');
-
-    # content-body parameters
-
-    $user->update( data => { ... } );
-
-    # query-string parameters
-
-    $user->update( query => { ... } );
-
-    # or
-
-    my $user = $twitter->users('lookup');
-
-    $user->update( ... );
-
-    # equivalent to
-
-    $twitter->resource('users')->action(
-        put => ( query => { ... }, data => { ... } )
-    );
-
-This example illustrates how you might update a new API resource.
-
-=head2 Deleting
-
-    my $users = $twitter->users;
-    my $user  = $users->resource('lookup');
-
-    # content-body parameters
-
-    $user->delete( data => { ... } );
-
-    # query-string parameters
-
-    $user->delete( query => { ... } );
-
-    # or
-
-    my $user = $twitter->users('lookup');
-
-    $user->delete( ... );
-
-    # equivalent to
-
-    $twitter->resource('users')->action(
-        delete => ( query => { ... }, data => { ... } )
-    );
-
-This example illustrates how you might delete an API resource.
-
-=head2 Transacting
-
-    my $users = $twitter->resource('users', 'lookup');
-
-    my ($results, $transaction) = $users->action( ... );
-
-    my $request  = $transaction->req;
-    my $response = $transaction->res;
-
-    my $headers;
-
-    $headers = $request->headers;
-    $headers = $response->headers;
-
-    # etc
-
-This example illustrates how you can access the transaction object used
-represent and process the HTTP transaction.
-
-=head1 PARAMETERS
+=head1 ATTRIBUTES
 
 =head2 access_token
 
     $twitter->access_token;
     $twitter->access_token('ACCESS_TOKEN');
 
-The access_token parameter should be set to an API access_token associated with
+The access_token attribute should be set to an API access_token associated with
 your account.
 
 =head2 access_token_secret
@@ -388,7 +197,7 @@ your account.
     $twitter->access_token_secret;
     $twitter->access_token_secret('ACCESS_TOKEN_SECRET');
 
-The access_token_secret parameter should be set to an API access_token_secret
+The access_token_secret attribute should be set to an API access_token_secret
 associated with your account.
 
 =head2 consumer_key
@@ -396,7 +205,7 @@ associated with your account.
     $twitter->consumer_key;
     $twitter->consumer_key('CONSUMER_KEY');
 
-The consumer_key parameter should be set to an API consumer_key associated with
+The consumer_key attribute should be set to an API consumer_key associated with
 your account.
 
 =head2 consumer_secret
@@ -404,7 +213,7 @@ your account.
     $twitter->consumer_secret;
     $twitter->consumer_secret('CONSUMER_SECRET');
 
-The consumer_secret parameter should be set to an API consumer_secret
+The consumer_secret attribute should be set to an API consumer_secret
 associated with your account.
 
 =head2 identifier
@@ -412,9 +221,7 @@ associated with your account.
     $twitter->identifier;
     $twitter->identifier('IDENTIFIER');
 
-The identifier parameter should be set to a string that identifies your app.
-
-=head1 ATTRIBUTES
+The identifier attribute should be set to a string that identifies your app.
 
 =head2 debug
 
